@@ -2,7 +2,7 @@
 #
 # SPDX-License-Identifier: Apache-2.0
 
-__version__ = "4.2.4"
+__version__ = "5.0.2"
 
 import logging
 import os, time
@@ -13,7 +13,7 @@ import shutil
 import sys
 import argparse
 import json
-from xml.etree import cElementTree as et
+from defusedxml import cElementTree as defused_et
 from .uccrestbuilder.global_config import (
     GlobalConfigBuilderSchema,
     GlobalConfigPostProcessor,
@@ -21,6 +21,7 @@ from .uccrestbuilder.global_config import (
 from .uccrestbuilder import build
 from .start_alert_build import alert_build
 
+import jsonschema
 from jinja2 import Environment, FileSystemLoader
 from dunamai import Version, Style
 import configparser
@@ -164,6 +165,53 @@ def handle_update(config_path):
         # upadating new changes in globalConfig.json 
         with open(config_path, "w") as config_file:
             json.dump(schema_content,config_file, ensure_ascii=False, indent=4)
+    
+    # check for schemaVersion, if it's less than 0.0.2 then updating globalConfig.json
+    if version_tuple(version) < version_tuple("0.0.2"):
+        ta_tabs = schema_content.get("pages").get("configuration",{}).get("tabs",{})
+
+        # check for schema changes in configuration page of globalConfig.json
+        for tab in ta_tabs:
+            if tab["name"] == "account":
+                conf_entities = tab.get("entity")
+                oauth_state_enabled_entity = {}
+                for entity in conf_entities:
+                    if entity.get("field") == "oauth_state_enabled":
+                        logger.warn("oauth_state_enabled field is no longer a separate entity since UCC version 5.0.0. It is now an option in the oauth field. Please update the globalconfig.json file accordingly.")
+                        oauth_state_enabled_entity = entity
+
+                    if entity.get("field") == "oauth" and not entity.get("options",{}).get("oauth_state_enabled"):
+                            entity["options"]["oauth_state_enabled"] = False
+                
+                if oauth_state_enabled_entity:
+                    conf_entities.remove(oauth_state_enabled_entity)
+            
+            tab_options = tab.get("options", {})
+            if tab_options.get("onChange"):
+                logger.error("The onChange option is no longer supported since UCC version 5.0.0. You can use custom hooks to implement these actions.")
+                del tab_options["onChange"]
+            if tab_options.get("onLoad"):
+                logger.error("The onLoad option is no longer supported since UCC version 5.0.0. You can use custom hooks to implement these actions.")
+                del tab_options["onLoad"]
+        
+        is_inputs = ("inputs" in schema_content.get("pages"))
+        if is_inputs:
+            services = schema_content.get("pages").get("inputs",{}).get("services",{})
+            # check in every Input service for onSave and onLoad options
+            for service in services:
+                service_options = service.get("options", {})
+                if service_options.get("onChange"):
+                    logger.error("The onChange option is no longer supported since UCC version 5.0.0. You can use custom hooks to implement these actions.")
+                    del service_options["onChange"]
+                if service_options.get("onLoad"):
+                    logger.error("The onLoad option is no longer supported since UCC version 5.0.0. You can use custom hooks to implement these actions.")
+                    del service_options["onLoad"]
+
+        schema_content["meta"]["schemaVersion"] = "0.0.2"
+        # upadating new changes in globalConfig.json 
+        with open(config_path, "w") as config_file:
+            json.dump(schema_content,config_file, ensure_ascii=False, indent=4)
+    
     return schema_content
     
 
@@ -538,7 +586,7 @@ def handle_no_inputs(ta_name):
         Args:
             path (str) : path to default.xml
         """
-        tree = et.parse(path)
+        tree = defused_et.parse(path)
         root = tree.getroot()
 
         for element in root:
@@ -593,6 +641,19 @@ def restore_comments(outputdir, ta_name, comment_map):
     with open(config_file, 'w') as file:
         file.write(''.join(lines))
 
+
+def validate_config_against_schema(config: dict):
+    """
+    Validates config against JSON schema.
+    Raises jsonschema.ValidationError if config is not valid.
+    """
+    schema_path = os.path.join(sourcedir, "schema", "schema.json")
+    with open(schema_path, "r") as f_schema:
+        schema_raw = f_schema.read()
+        schema = json.loads(schema_raw)
+    return jsonschema.validate(instance=config, schema=schema)
+
+
 def main():
     parser = argparse.ArgumentParser(description="Build the add-on")
     parser.add_argument(
@@ -606,28 +667,30 @@ def main():
         "--config",
         type=str,
         nargs='?',
-        help="Path to configuration file, Defaults to GlobalConfig.json in parent directory of source provided",
+        help="Path to configuration file, defaults to GlobalConfig.json in parent directory of source provided",
         default=None
     )
-    version = Version.from_git()
-    if not version.stage:
-        stage = 'R'
-    else:
-        stage = version.stage[:1]
-    
-    version_str = version.serialize(metadata=True,style=Style.SemVer)
-    version_splunk = f"{version.base}{stage}{version.commit}"
-    
     parser.add_argument(
         "--ta-version",
         type=str,
-        help="Version of TA, Deafult version is version specified in the package such as app.manifest, app.conf, and globalConfig.json",
-        default = version_splunk
+        help="Version of TA, default version is version specified in the package such as app.manifest, app.conf, and globalConfig.json",
+        default=None
     )
     args = parser.parse_args()
-    ta_version = args.ta_version.strip()
-    if not ta_version:
+    if not args.ta_version:
+        version = Version.from_git()
+        if not version.stage:
+            stage = 'R'
+        else:
+            stage = version.stage[:1]
+
+        version_str = version.serialize(metadata=True, style=Style.SemVer)
+        version_splunk = f"{version.base}{stage}{version.commit}"
         ta_version = version_splunk
+    else:
+        ta_version = args.ta_version.strip()
+        version_str = ta_version
+
     if not os.path.exists(args.source):
         raise NotADirectoryError("{} not Found.".format(os.path.abspath(args.source)))
 
@@ -643,6 +706,16 @@ def main():
         ta_name = manifest['info']['id']['name']
 
     if os.path.exists(args.config):
+        try:
+            with open(args.config, "r") as f_config:
+                config_raw = f_config.read()
+                config = json.loads(config_raw)
+            validate_config_against_schema(config)
+            logger.info("Config is valid")
+        except jsonschema.ValidationError as e:
+            logger.error("Config is not valid. Error: {}".format(e))
+            sys.exit(1)
+
         update_ta_version(args.config, ta_version)
 
         # handle_update check schemaVersion and update globalConfig.json if required and return schema
@@ -764,4 +837,4 @@ def main():
     if os.path.exists(os.path.abspath(os.path.join(args.source,PARENT_DIR,"additional_packaging.py"))):
         sys.path.insert(0,os.path.abspath(os.path.join(args.source,PARENT_DIR)))
         from additional_packaging import additional_packaging
-        additional_packaging(ta_name)
\ No newline at end of file
+        additional_packaging(ta_name)
